# About CrowdCent

CrowdCent is on a mission to decentralize investment management by changing the way investment funds make decisions and allocate capital. We are the machine learning and coordination layer for online investment communities looking to turn their data into actionable, investable portfolios.

More information about CrowdCent can be found on [crowdcent.com](https://crowdcent.com). 